#
# applsci-fishing.R, 31 Jul 22
#
# Data from:
# Supplementary Materials
# Forecasting the Project Duration Average and Standard Deviation from Deterministic Schedule Information
# Pablo Ballesteros-Pérez, Alberto Cerezo-Narváez, Manuel Otero-Mateo, Andrés Pastor-Fernández, Jingxiao Zhang, and Mario Vanhoucke
# and
# Duration and Cost Variability of Construction Activities: An Empirical Study
# P. Ballesteros-Pérez, E. Sanz-Ablanedo, R. Soetanto, Ma. C. González-Cruz, G. D. Larsen, and A. Cerezo-Narváez

library("colorspace")


par(bty="l")
par(las=1)
par(pch="+")
pal_col=rainbow(3)

# Building construction data
app=read.csv("applsci-10-00654-s001.csv",as.is=TRUE)

plot(app$Cost_planned, app$Cost_actual, log="xy")
lines(c(1, 1e6), c(1, 1e6), col="green")

capp_mod=glm(log(Cost_actual) ~ log(Cost_planned), data=app)
summary(capp_mod)

xbounds=exp(seq(0, 14, by=0.2))
pred=predict(capp_mod, newdata=data.frame(Cost_planned=xbounds))

plot(app$Duration_planned, app$Duration_actual, log="xy", col=pal_col[2],
	xlab="Planned duration (days)", ylab="Actual duration")
lines(c(1, 1e3), c(1, 1e3), col=pal_col[3])

dapp_mod=glm(log(Duration_actual) ~ log(Duration_planned), data=app)
# # The following models don't improve the fit
# dapp_mod=glm(Duration_actual ~ Duration_planned+I(Duration_planned^2), data=app)
# dapp_nmod=nls(Duration_actual ~ a+b*Duration_planned^c,
				start=c(a=10, b=0.1, c=1.5), data=app)
# summary(dapp_nmod)
# pred=predict(dapp_nmod, newdata=data.frame(Duration_planned=xbounds))
# 
# lines(xbounds, pred, col="red")

summary(dapp_mod)

pred=predict(dapp_mod, newdata=data.frame(Duration_planned=xbounds))

lines(xbounds, exp(pred), col=pal_col[1])

legend("bottomright", legend=c("Fitted regression line", "Data", "Estimate == Actual"),
                        fill=pal_col, border="white", bty="n")


# Road construction data
rd=read.csv("./road_Ballesteros-Perez.csv", as.is=TRUE)


x_bounds=exp(1:20)
plot(rd$Planned.cost, rd$Actual.cost, log="xy", col=pal_col[2],
	xlab="Planned cost", ylab="Actual cost")
lines(c(1, 1e9), c(1, 1e9), col=pal_col[3])

# rc_mod=glm(log(Actual.cost) ~ log(Planned.cost), data=rd)
# rc_mod=nls(Actual.cost ~ a+b*Planned.cost+c*Planned.cost^d, data=rd, trace=TRUE,
#                 start=c(a=-1e4, b=0.98, c=1e-5, d=1.5)) # Error singular gradient :-(
# rc_mod=nls(Actual.cost ~ a+b*Planned.cost^c, data=rd, trace=TRUE,
# 		start=c(a=1e4, b=1.1, c=1.1))
# rc_mod=glm(Actual.cost ~ Planned.cost+I(Planned.cost^2.0), data=rd) # The best fitting of the bunch
pc_mod=glm(Actual.cost ~ Planned.cost, data=rd)
summary(pc_mod)
pred=predict(pc_mod, newdata=data.frame(Planned.cost=x_bounds))
lines(x_bounds, pred, col=pal_col[1])


# Given the costs, I'm assuming the duration is in days and not hours
plot(rd$Planned.dur, rd$Actual.dur, log="xy", col=pal_col[2],
	xlab="Planned duration (days)", ylab="Actual duration")
lines(c(1, 1e4), c(1, 1e4), col=pal_col[3])

pd_mod=glm(log(Actual.dur) ~ log(Planned.dur), data=rd)
summary(pd_mod)
pred=predict(pd_mod, newdata=data.frame(Planned.dur=x_bounds))
lines(x_bounds, exp(pred), col=pal_col[1])

legend("bottomright", legend=c("Fitted regression line", "Data", "Estimate == Actual"),
                        fill=pal_col, border="white", bty="n")

# Adding cost to the model improves slightly improves the fit
pdc_mod=glm(Actual.dur ~ Planned.dur+log(Planned.cost), data=rd)
summary(pdc_mod)

cnt_pdur=count(rd$Planned.dur)

plot(cnt_pdur, log="xy")

# Most frequent durations
head(cnt_pdur[order(cnt_pdur$freq, decreasing=TRUE),], n=20)

# Frequency of last digit
count(rd$Planned.cost %% 10)

